[llvm-commits] CVS: llvm/include/llvm/Target/TargetAsmInfo.h

Anton Korobeynikov asl at math.spbu.ru
Tue May 1 15:23:41 PDT 2007



Changes in directory llvm/include/llvm/Target:

TargetAsmInfo.h updated: 1.31 -> 1.32
---
Log message:

Fix couple of bugs connected with eh info:
1. Correct output offsets on Linux
2. Fix "style" of personality function. It shouldn't be indirect.


---
Diffs of the changes:  (+13 -6)

 TargetAsmInfo.h |   19 +++++++++++++------
 1 files changed, 13 insertions(+), 6 deletions(-)


Index: llvm/include/llvm/Target/TargetAsmInfo.h
diff -u llvm/include/llvm/Target/TargetAsmInfo.h:1.31 llvm/include/llvm/Target/TargetAsmInfo.h:1.32
--- llvm/include/llvm/Target/TargetAsmInfo.h:1.31	Sun Apr 29 14:17:45 2007
+++ llvm/include/llvm/Target/TargetAsmInfo.h	Tue May  1 17:23:12 2007
@@ -263,10 +263,14 @@
 
     //===--- Dwarf Emission Directives -----------------------------------===//
 
-    /// AbsoluteSectionOffsets - True if we should emit abolute section
-    /// offsets. Defaults to false.
-    bool AbsoluteSectionOffsets;
-    
+    /// AbsoluteDebugSectionOffsets - True if we should emit abolute section
+    /// offsets for debug information. Defaults to false.
+    bool AbsoluteDebugSectionOffsets;
+
+    /// AbsoluteEHSectionOffsets - True if we should emit abolute section
+    /// offsets for EH information. Defaults to false.
+    bool AbsoluteEHSectionOffsets;
+
     /// HasLEB128 - True if target asm supports leb128 directives.
     ///
     bool HasLEB128; // Defaults to false.
@@ -530,8 +534,11 @@
     const char *getProtectedDirective() const {
       return ProtectedDirective;
     }
-    bool isAbsoluteSectionOffsets() const {
-      return AbsoluteSectionOffsets;
+    bool isAbsoluteDebugSectionOffsets() const {
+      return AbsoluteDebugSectionOffsets;
+    }
+    bool isAbsoluteEHSectionOffsets() const {
+      return AbsoluteEHSectionOffsets;
     }
     bool hasLEB128() const {
       return HasLEB128;






More information about the llvm-commits mailing list